@@ -339,18 +339,10 @@ class Player(GObject.GObject):
 
     @log
     def _sync_playing(self):
-        if self._get_playing():
-            image = self._pauseImage
-            tooltip = _("Pause")
-        else:
-            image = self._playImage
-            tooltip = _("Play")
-
+        image = self._pauseImage if self._get_playing() else self._playImage
         if self.playBtn.get_image() != image:
             self.playBtn.set_image(image)
 
-        self.playBtn.set_tooltip_text(tooltip)
-
     @log
     def _sync_prev_next(self):
         hasNext = self.has_next()
