@@ -52,7 +52,13 @@ from gnomemusic import log
 import logging
 logger = logging.getLogger(__name__)
 
-tracker = Tracker.SparqlConnection.get(None)
+try:
+    tracker = Tracker.SparqlConnection.get(None)
+except Exception as e:
+    from sys import exit
+    logger.error("Cannot connect to tracker, error '%s'\Exiting" % str(e))
+    exit(1)
+
 playlists = Playlists.get_default()
 
 if Gtk.get_minor_version() > 8:
@@ -234,7 +240,7 @@ class ViewContainer(Stack):
         vScrollbar = self.view.get_vscrollbar()
         revealAreaHeight = 32
 
-        #if there's no vscrollbar, or if it's not visible, hide the button
+        # if there's no vscrollbar, or if it's not visible, hide the button
         if not vScrollbar or not vScrollbar.get_visible():
             self._loadMore.set_block(True)
             return
@@ -244,7 +250,7 @@ class ViewContainer(Stack):
         page_size = self.vadjustment.get_page_size()
 
         end = False
-        #special case self values which happen at construction
+        # special case self values which happen at construction
         if (value == 0) and (upper == 1) and (page_size == 1):
             end = False
         else:
@@ -336,7 +342,7 @@ class ViewContainer(Stack):
         callback([])
 
 
-#Class for the Empty View
+# Class for the Empty View
 class Empty(Stack):
     @log
     def __init__(self, header_bar, player):
@@ -357,7 +363,7 @@ class Albums(ViewContainer):
     def __init__(self, header_bar, selection_toolbar, player):
         ViewContainer.__init__(self, _("Albums"), header_bar,
                                selection_toolbar, Gd.MainViewType.ICON)
-        self.countQuery = Query.ALBUMS_COUNT
+        self.countQuery = Query.get_albums_count()
         self._albumWidget = Widgets.AlbumWidget(player)
         self.player = player
         self.add(self._albumWidget)
@@ -436,7 +442,7 @@ class Songs(ViewContainer):
     @log
     def __init__(self, header_bar, selection_toolbar, player):
         ViewContainer.__init__(self, _("Songs"), header_bar, selection_toolbar, Gd.MainViewType.LIST)
-        self.countQuery = Query.SONGS_COUNT
+        self.countQuery = Query.get_songs_count()
         self._items = {}
         self.monitors = []
         self.isStarred = None
@@ -570,15 +576,12 @@ class Songs(ViewContainer):
         list_widget.add_renderer(type_renderer,
                                  self._on_list_widget_type_render, None)
 
-    @log
     def _on_list_widget_title_render(self, col, cell, model, _iter, data):
         pass
 
-    @log
     def _on_list_widget_star_render(self, col, cell, model, _iter, data):
         pass
 
-    @log
     def _on_list_widget_duration_render(self, col, cell, model, _iter, data):
         item = model.get_value(_iter, 5)
         if item:
@@ -587,11 +590,9 @@ class Songs(ViewContainer):
             seconds %= 60
             cell.set_property('text', '%i:%02i' % (minutes, seconds))
 
-    @log
     def _on_list_widget_artist_render(self, col, cell, model, _iter, data):
         pass
 
-    @log
     def _on_list_widget_type_render(self, coll, cell, model, _iter, data):
         item = model.get_value(_iter, 5)
         if item:
@@ -952,15 +953,12 @@ class Playlist(ViewContainer):
         cols[0].clear_attributes(type_renderer)
         cols[0].add_attribute(type_renderer, "text", 2)
 
-    @log
     def _on_list_widget_title_render(self, col, cell, model, _iter, data):
         pass
 
-    @log
     def _on_list_widget_star_render(self, col, cell, model, _iter, data):
         pass
 
-    @log
     def _on_list_widget_duration_render(self, col, cell, model, _iter, data):
         item = model.get_value(_iter, 5)
         if item:
@@ -969,11 +967,9 @@ class Playlist(ViewContainer):
             seconds %= 60
             cell.set_property('text', '%i:%02i' % (minutes, seconds))
 
-    @log
     def _on_list_widget_artist_render(self, col, cell, model, _iter, data):
         pass
 
-    @log
     def _on_list_widget_type_render(self, coll, cell, model, _iter, data):
         item = model.get_value(_iter, 5)
         if item:
@@ -1140,9 +1136,36 @@ class Playlist(ViewContainer):
             else:
                 return
 
+        update_playing_track = False
         for row in model:
             if row[5].get_url() == uri:
-                self._model.remove(row.iter)
+                # Is the removed track now being played?
+                if name == self.current_playlist:
+                    if self.player.currentTrack is not None:
+                        currentTrackpath = self.player.currentTrack.get_path().to_string()
+                        if row.path is not None and row.path.to_string() == currentTrackpath:
+                            update_playing_track = True
+
+                model.remove(row.iter)
+
+                # Reload the model and switch to next song
+                if update_playing_track:
+                    if row.iter is None:
+                        # Get first track if next track is not valid
+                        row.iter = model.get_iter_first()
+                        if row.iter is None:
+                            # Last track was removed
+                            return
+
+                    self.iter_to_clean = None
+                    # row.iter will give us next iter to start playing
+                    # convert it to filter iter
+                    row.iter = self.filter.convert_child_iter_to_iter(row.iter)[1]
+                    self.update_model(self.player, self.filter, row.iter)
+                    self.player.set_playlist('Playlist', name, self.filter, row.iter, 5)
+                    self.player.set_playing(True)
+
+                # Update songs count
                 self.songs_count -= 1
                 self._update_songs_count()
                 return
