@@ -33,7 +33,6 @@
 
 from gi.repository import Gtk, Gd, GLib, GObject, Pango
 from gi.repository import GdkPixbuf, Gio
-from gi.repository import Grl
 from gi.repository import Tracker
 from gettext import gettext as _, ngettext
 from gnomemusic.grilo import grilo
@@ -45,7 +44,14 @@ import logging
 logger = logging.getLogger(__name__)
 
 playlist = Playlists.get_default()
-tracker = Tracker.SparqlConnection.get(None)
+
+try:
+    tracker = Tracker.SparqlConnection.get(None)
+except Exception as e:
+    from sys import exit
+    logger.error("Cannot connect to tracker, error '%s'\Exiting" % str(e))
+    exit(1)
+
 ALBUM_ART_CACHE = AlbumArtCache.get_default()
 if Gtk.Widget.get_default_direction() is not Gtk.TextDirection.RTL:
     NOW_PLAYING_ICON_NAME = 'media-playback-start-symbolic'
@@ -161,7 +167,7 @@ class AlbumWidget(Gtk.EventBox):
                 item = self.model.get_value(self.iterToClean, 5)
                 title = AlbumArtCache.get_media_title(item)
                 self.model.set_value(self.iterToClean, 0, title)
-                #Hide now playing icon
+                # Hide now playing icon
                 self.model.set_value(self.iterToClean, 6, False)
             self.player.set_playlist('Album', self.album, self.model, _iter, 5)
             self.player.set_playing(True)
@@ -342,7 +348,7 @@ class AlbumWidget(Gtk.EventBox):
 
     @log
     def update_model(self, player, playlist, currentIter):
-        #self is not our playlist, return
+        # self is not our playlist, return
         if (playlist != self.model):
             return False
         currentSong = playlist.get_value(currentIter, 5)
@@ -422,11 +428,11 @@ class ArtistAlbums(Gtk.VBox):
 
     @log
     def update_model(self, player, playlist, currentIter):
-        #this is not our playlist, return
+        # this is not our playlist, return
         if playlist != self.model:
-            #TODO, only clean once, but that can wait util we have clean
-            #the code a bit, and until the playlist refactoring.
-            #the overhead is acceptable for now
+            # TODO, only clean once, but that can wait util we have clean
+            # the code a bit, and until the playlist refactoring.
+            # the overhead is acceptable for now
             self.clean_model()
             return False
 
@@ -477,7 +483,7 @@ class AllArtistsAlbums(ArtistAlbums):
     def __init__(self, player):
         ArtistAlbums.__init__(self, _("All Artists"), [], player)
         self._offset = 0
-        self.countQuery = Query.ALBUMS_COUNT
+        self.countQuery = Query.get_albums_count()
         self._cached_count = -1
         self._load_more = LoadMoreButton(self._get_remaining_item_count)
         self.pack_end(self._load_more.widget, False, False, 0)
